@@ -5,8 +5,8 @@
 #' a cdm_reference object.
 #' @inheritParams interval
 #' @param output Output format. It can be either the number of records
-#' ("records") that are in observation in the specific interval of time, the
-#' number of person-days ("person-days"), or both c("records","person-days").
+#' ("record") that are in observation in the specific interval of time, the
+#' number of person-days ("person-days"), the number of subjects ("person").
 #' @param ageGroup A list of age groups to stratify results by.
 #' @param sex Boolean variable. Whether to stratify by sex (TRUE) or not
 #' (FALSE).
@@ -22,7 +22,7 @@
 #' result <- summariseInObservation(
 #'   cdm$observation_period,
 #'   interval = "months",
-#'   output = c("person-days","records"),
+#'   output = c("person-days","record"),
 #'   ageGroup = list("<=60" = c(0,60), ">60" = c(61, Inf)),
 #'   sex = TRUE
 #' )
@@ -31,27 +31,25 @@
 #'   glimpse()
 #'
 #' PatientProfiles::mockDisconnect(cdm)
-#'
 #' }
 summariseInObservation <- function(observationPeriod,
                                    interval = "overall",
-                                   output = "records",
+                                   output = "record",
                                    ageGroup = NULL,
-                                   sex = FALSE, dateRange = NULL){
-
-  tablePrefix <-  omopgenerics::tmpPrefix()
+                                   sex = FALSE, dateRange = NULL) {
+  tablePrefix <- omopgenerics::tmpPrefix()
 
   # Initial checks ----
   omopgenerics::assertClass(observationPeriod, "omop_table")
   omopgenerics::assertTrue(omopgenerics::tableName(observationPeriod) == "observation_period")
   dateRange <- validateStudyPeriod(omopgenerics::cdmReference(observationPeriod), dateRange)
 
-  if(omopgenerics::isTableEmpty(observationPeriod)){
+  if (omopgenerics::isTableEmpty(observationPeriod)) {
     cli::cli_warn("observation_period table is empty. Returning an empty summarised result.")
     return(omopgenerics::emptySummarisedResult(settings = createSettings(result_type = "summarise_in_observation")))
   }
 
-  checkOutput(output)
+  omopgenerics::assertChoice(output, choices = c("person-days","record", "person"), call = parent.frame())
   ageGroup <- omopgenerics::validateAgeGroupArgument(ageGroup, ageGroupName = "")[[1]]
   omopgenerics::assertLogical(sex, length = 1)
   original_interval <- interval
@@ -59,8 +57,12 @@ summariseInObservation <- function(observationPeriod,
   interval <- x$interval
   unitInterval <- x$unitInterval
 
-  if(length(output) > 1){output <- "all"}
-  if(missing(ageGroup) | is.null(ageGroup)){ageGroup <- list("overall" = c(0,Inf))}else{ageGroup <- append(ageGroup, list("overall" = c(0, Inf)))}
+  if (missing(ageGroup) | is.null(ageGroup)) {
+    ageGroup <- list("overall" = c(0, Inf))
+  } else {
+    ageGroup <- append(ageGroup, list("overall" = c(0, Inf)))
+  }
+
 
   # Create initial variables ----
   cdm <- omopgenerics::cdmReference(observationPeriod)
@@ -71,15 +73,15 @@ summariseInObservation <- function(observationPeriod,
 
   name <- "observation_period"
   start_date_name <- omopgenerics::omopColumns(table = name, field = "start_date")
-  end_date_name   <- omopgenerics::omopColumns(table = name, field = "end_date")
+  end_date_name <- omopgenerics::omopColumns(table = name, field = "end_date")
 
   # Observation period ----
-  if(interval != "overall"){
+  if (interval != "overall") {
     timeInterval <- getIntervalTibbleForObservation(observationPeriod, start_date_name, end_date_name, interval, unitInterval)
 
     # Insert interval table to the cdm ----
     cdm <- cdm |>
-      omopgenerics::insertTable(name = paste0(tablePrefix,"interval"), table = timeInterval)
+      omopgenerics::insertTable(name = paste0(tablePrefix, "interval"), table = timeInterval)
   }
 
   # Count records ----
@@ -90,125 +92,138 @@ summariseInObservation <- function(observationPeriod,
   result <- addSexOverall(result, sex)
 
   # Create summarisedResult
-  result <- createSummarisedResultObservationPeriod(result, observationPeriod, name, denominator,dateRange, original_interval)
+  result <- createSummarisedResultObservationPeriod(result, observationPeriod, name, denominator, dateRange, original_interval)
 
   CDMConnector::dropSourceTable(cdm, name = dplyr::starts_with(tablePrefix))
   return(result)
 }
 
+
 getDenominator <- function(cdm, output){
-  if(output == "records"){
-    tibble::tibble(
+  if("record" %in% output){
+    denominator_record <- tibble::tibble(
       "denominator" = c(cdm[["person"]] |>
                           dplyr::ungroup() |>
                           dplyr::select("person_id") |>
                           dplyr::summarise("n" = dplyr::n()) |>
                           dplyr::pull("n")),
       "variable_name" = "Number records in observation")
-  }else if(output == "person-days"){
-    y <- cdm[["observation_period"]] |>
-      dplyr::ungroup() |>
-      dplyr::inner_join(cdm[["person"]] |> dplyr::select("person_id"), by = "person_id") %>%
-      dplyr::mutate(n = !!CDMConnector::datediff("observation_period_start_date", "observation_period_end_date",interval = "day")+1) |>
-      dplyr::summarise("n" = sum(.data$n, na.rm = TRUE)) |>
-      dplyr::pull("n")
-
-    tibble::tibble(
-      "denominator" = y,
-      "variable_name" = "Number person-days")
-
-  }else if(output == "all"){
-    y <- cdm[["observation_period"]] |>
-      dplyr::ungroup() |>
-      dplyr::inner_join(cdm[["person"]] |> dplyr::select("person_id"), by = "person_id") %>%
-      dplyr::mutate(n = !!CDMConnector::datediff("observation_period_start_date", "observation_period_end_date",interval = "day")+1) |>
-      dplyr::summarise("n" = sum(.data$n, na.rm = TRUE)) |>
-      dplyr::pull("n")
-
-    tibble::tibble(
+  } else {
+    denominator_record <- tibble::tibble()
+  }
+  if("person" %in% output){
+    denominator_person <- tibble::tibble(
       "denominator" = c(cdm[["person"]] |>
                           dplyr::ungroup() |>
                           dplyr::select("person_id") |>
                           dplyr::summarise("n" = dplyr::n()) |>
-                          dplyr::pull("n"),
-                        y
-      ),
-      "variable_name" = c("Number records in observation","Number person-days"))
+                          dplyr::pull("n")),
+      "variable_name" = "Number subjects in observation")
+  } else {
+    denominator_person <- tibble::tibble()
   }
+  if("person-days" %in% output){
+    y <- cdm[["observation_period"]] |>
+      dplyr::ungroup() |>
+      dplyr::inner_join(cdm[["person"]] |> dplyr::select("person_id"), by = "person_id") %>%
+      dplyr::mutate(n = !!CDMConnector::datediff("observation_period_start_date", "observation_period_end_date", interval = "day") + 1) |>
+      dplyr::summarise("n" = sum(.data$n, na.rm = TRUE)) |>
+      dplyr::pull("n")
+
+    denominator_pd <- tibble::tibble(
+      "denominator" = y,
+      "variable_name" = "Number person-days")
+    
+  } else {
+    denominator_pd <- tibble::tibble()
+  }
+
+  denominator <- rbind(denominator_record, denominator_person, denominator_pd)
+  return(denominator)
 }
 
-getIntervalTibbleForObservation <- function(omopTable, start_date_name, end_date_name, interval, unitInterval){
+getIntervalTibbleForObservation <- function(omopTable, start_date_name, end_date_name, interval, unitInterval) {
   startDate <- getOmopTableStartDate(omopTable, start_date_name)
-  endDate   <- getOmopTableEndDate(omopTable, end_date_name)
+  endDate <- getOmopTableEndDate(omopTable, end_date_name)
 
   tibble::tibble(
     "group" = seq.Date(startDate, endDate, .env$interval)
   ) |>
     dplyr::rowwise() |>
-    dplyr::mutate("interval" = max(which(
-      .data$group >= seq.Date(from = startDate, to = endDate, by = paste(.env$unitInterval, .env$interval))
-    ),
-    na.rm = TRUE)) |>
+    dplyr::mutate("interval" = max(
+      which(
+        .data$group >= seq.Date(from = startDate, to = endDate, by = paste(.env$unitInterval, .env$interval))
+      ),
+      na.rm = TRUE
+    )) |>
     dplyr::ungroup() |>
     dplyr::group_by(.data$interval) |>
     dplyr::mutate(
       "interval_start_date" = min(.data$group),
-      "interval_end_date"   = dplyr::if_else(.env$interval == "year",
-                                             clock::add_years(min(.data$group),.env$unitInterval)-1,
-                                             clock::add_months(min(.data$group),.env$unitInterval)-1)
+      "interval_end_date" = dplyr::if_else(.env$interval == "year",
+        clock::add_years(min(.data$group), .env$unitInterval) - 1,
+        clock::add_months(min(.data$group), .env$unitInterval) - 1
+      )
     ) |>
     dplyr::mutate(
       "interval_start_date" = as.Date(.data$interval_start_date),
       "interval_end_date" = as.Date(.data$interval_end_date)
     ) |>
     dplyr::mutate(
-      "time_interval" = paste(.data$interval_start_date,"to",.data$interval_end_date)
+      "time_interval" = paste(.data$interval_start_date, "to", .data$interval_end_date)
     ) |>
     dplyr::ungroup() |>
     dplyr::select("interval_start_date", "interval_end_date", "time_interval") |>
     dplyr::distinct()
 }
 
+
 countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name, interval, output, tablePrefix){
 
-  if(output == "person-days" | output == "all"){
+  if("person-days" %in% output){
     if(interval != "overall"){
+      
       x <- cdm[[paste0(tablePrefix, "interval")]] |>
         dplyr::cross_join(
           observationPeriod |>
-            dplyr::select("start_date" = "observation_period_start_date",
-                          "end_date"   = "observation_period_end_date",
-                          "age_group", "sex","person_id")
+            dplyr::select(
+              "start_date" = "observation_period_start_date",
+              "end_date" = "observation_period_end_date",
+              "age_group", "sex", "person_id"
+            )
         ) |>
         dplyr::filter((.data$start_date < .data$interval_start_date & .data$end_date >= .data$interval_start_date) |
-                        (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) %>%
+          (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) %>%
         dplyr::mutate(start_date = dplyr::if_else(!is.na(.data$start_date) & .data$start_date >= .data$interval_start_date, .data$start_date, .data$interval_start_date)) |>
-        dplyr::mutate(end_date   = dplyr::if_else(!is.na(.data$end_date) & .data$end_date <= .data$interval_end_date, .data$end_date, .data$interval_end_date)) |>
+        dplyr::mutate(end_date = dplyr::if_else(!is.na(.data$end_date) & .data$end_date <= .data$interval_end_date, .data$end_date, .data$interval_end_date)) |>
         dplyr::compute(temporary = FALSE, name = tablePrefix)
       additional_column <- "time_interval"
-    }else{
+    } else {
       x <- observationPeriod |>
-        dplyr::rename("start_date" = "observation_period_start_date",
-                      "end_date"   = "observation_period_end_date")
+        dplyr::rename(
+          "start_date" = "observation_period_start_date",
+          "end_date" = "observation_period_end_date"
+        )
       additional_column <- character()
     }
 
     personDays <- x %>%
-      dplyr::mutate(estimate_value = !!CDMConnector::datediff("start_date","end_date", interval = "day")+1) |>
-      dplyr::group_by(dplyr::across(dplyr::any_of(c( "sex", "age_group","time_interval")))) |>
+      dplyr::mutate(estimate_value = !!CDMConnector::datediff("start_date", "end_date", interval = "day") + 1) |>
+      dplyr::group_by(dplyr::across(dplyr::any_of(c("sex", "age_group", "time_interval")))) |>
       dplyr::summarise(estimate_value = sum(.data$estimate_value, na.rm = TRUE), .groups = "drop") |>
-      dplyr::mutate("variable_name" = "Number person-days")|>
+      dplyr::mutate("variable_name" = "Number person-days") |>
       dplyr::collect()
-  }else{
+  } else {
     personDays <- createEmptyIntervalTable(interval)
   }
 
-  if(output == "records" | output == "all"){
+  if("record" %in% output){
 
     if(interval != "overall"){
+
       x <- observationPeriod |>
-        dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))),"-",as.character(as.integer(clock::get_month(.data[[start_date_name]]))),"-01"))) |>
-        dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))),"-",as.character(as.integer(clock::get_month(.data[[end_date_name]]))),"-01"))) |>
+        dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[start_date_name]]))), "-01"))) |>
+        dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))), "-", as.character(as.integer(clock::get_month(.data[[end_date_name]]))), "-01"))) |>
         dplyr::group_by(.data$start_date, .data$end_date, .data$age_group, .data$sex) |>
         dplyr::summarise(estimate_value = dplyr::n(), .groups = "drop") |>
         dplyr::compute(temporary = FALSE, name = tablePrefix)
@@ -216,13 +231,13 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
       records <- cdm[[paste0(tablePrefix, "interval")]] |>
         dplyr::cross_join(x) |>
         dplyr::filter((.data$start_date < .data$interval_start_date & .data$end_date >= .data$interval_start_date) |
-                        (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
+          (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
         dplyr::group_by(.data$time_interval, .data$age_group, .data$sex) |>
         dplyr::summarise(estimate_value = sum(.data$estimate_value, na.rm = TRUE), .groups = "drop") |>
         dplyr::mutate("variable_name" = "Number records in observation") |>
         dplyr::collect()
       additional_column <- "time_interval"
-    }else{
+    } else {
       records <- observationPeriod |>
         dplyr::group_by(.data$age_group, .data$sex) |>
         dplyr::summarise(estimate_value = dplyr::n(), .groups = "drop") |>
@@ -230,35 +245,70 @@ countRecords <- function(observationPeriod, cdm, start_date_name, end_date_name,
         dplyr::collect()
       additional_column <- character()
     }
-  }else{
+  } else {
     records <- createEmptyIntervalTable(interval)
   }
 
+  if("person" %in% output){
+
+    if(interval != "overall"){
+      x <- observationPeriod |>
+        dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[start_date_name]]))),"-",as.character(as.integer(clock::get_month(.data[[start_date_name]]))),"-01"))) |>
+        dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data[[end_date_name]]))),"-",as.character(as.integer(clock::get_month(.data[[end_date_name]]))),"-01"))) |>
+        dplyr::group_by(.data$start_date, .data$end_date, .data$age_group, .data$sex) |>
+        dplyr::summarise(estimate_value = dplyr::n_distinct("person_id"), .groups = "drop") |>
+        dplyr::compute(temporary = FALSE, name = tablePrefix)
+
+      subjects <- cdm[[paste0(tablePrefix, "interval")]] |>
+        dplyr::cross_join(x) |>
+        dplyr::filter((.data$start_date < .data$interval_start_date & .data$end_date >= .data$interval_start_date) |
+                        (.data$start_date >= .data$interval_start_date & .data$start_date <= .data$interval_end_date)) |>
+        dplyr::group_by(.data$time_interval, .data$age_group, .data$sex) |>
+        dplyr::summarise(estimate_value = sum(.data$estimate_value, na.rm = TRUE), .groups = "drop") |>
+        dplyr::mutate("variable_name" = "Number subjects in observation") |>
+        dplyr::collect()
+      additional_column <- "time_interval"
+    }else{
+      subjects <- observationPeriod |>
+        dplyr::group_by(.data$age_group, .data$sex) |>
+        dplyr::summarise(estimate_value = dplyr::n_distinct("person_id"), .groups = "drop") |>
+        dplyr::mutate("variable_name" = "Number subjects in observation") |>
+        dplyr::collect()
+      additional_column <- character()
+    }
+  }else{
+    subjects <- createEmptyIntervalTable(interval)
+  }
+
+
+
   x <- personDays |>
     dplyr::mutate(estimate_value = as.numeric(.data$estimate_value)) |>
     rbind(
       records |>
+        dplyr::mutate(estimate_value = as.numeric(.data$estimate_value)),
+      subjects |>
         dplyr::mutate(estimate_value = as.numeric(.data$estimate_value))
     ) |>
-    omopgenerics::uniteAdditional(additional_column)|>
+    omopgenerics::uniteAdditional(additional_column) |>
     dplyr::arrange(dplyr::across(dplyr::any_of("additional_level")))
 
   return(x)
 }
 
-createSummarisedResultObservationPeriod <- function(result, observationPeriod, name, denominator, dateRange,original_interval){
+createSummarisedResultObservationPeriod <- function(result, observationPeriod, name, denominator, dateRange, original_interval) {
   if (dim(result)[1] == 0) {
-    result<-omopgenerics::emptySummarisedResult() |>
-      omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange)|>
-                                          dplyr::mutate("interval" = .env$original_interval))
-  }else{
+    result <- omopgenerics::emptySummarisedResult() |>
+      omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange) |>
+        dplyr::mutate("interval" = .env$original_interval))
+  } else {
     result <- result |>
-      dplyr::mutate("estimate_value" = sprintf('%.0f', .data$estimate_value)) |>
+      dplyr::mutate("estimate_value" = sprintf("%.0f", .data$estimate_value)) |>
       omopgenerics::uniteStrata(cols = c("sex", "age_group")) |>
       dplyr::mutate(
         "result_id" = as.integer(1),
         "cdm_name" = omopgenerics::cdmName(omopgenerics::cdmReference(observationPeriod)),
-        "group_name"  = "omop_table",
+        "group_name" = "omop_table",
         "group_level" = name,
         "variable_level" = as.character(NA),
         "estimate_name" = "count",
@@ -270,12 +320,11 @@ createSummarisedResultObservationPeriod <- function(result, observationPeriod, n
       dplyr::group_by(.data$additional_level, .data$strata_level, .data$variable_name) |>
       dplyr::mutate(estimate_type = dplyr::if_else(dplyr::row_number() == 2, "percentage", .data$estimate_type)) |>
       dplyr::inner_join(denominator, by = "variable_name") |>
-      dplyr::mutate(estimate_value = dplyr::if_else(.data$estimate_type == "percentage", as.character(as.numeric(.data$estimate_value)/denominator*100), .data$estimate_value)) |>
+      dplyr::mutate(estimate_value = dplyr::if_else(.data$estimate_type == "percentage", as.character(as.numeric(.data$estimate_value) / denominator * 100), .data$estimate_value)) |>
       dplyr::select(-c("denominator")) |>
       dplyr::mutate(estimate_name = dplyr::if_else(.data$estimate_type == "percentage", "percentage", .data$estimate_name)) |>
-      omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange)|>
-                                          dplyr::mutate("interval" = .env$original_interval)
-      )
+      omopgenerics::newSummarisedResult(settings = createSettings(result_type = "summarise_in_observation", study_period = dateRange) |>
+        dplyr::mutate("interval" = .env$original_interval))
   }
   return(result)
 }
@@ -339,8 +388,8 @@ addStrataToPeopleInObservation <- function(cdm, ageGroup, sex, tablePrefix, date
   return(demographics)
 }
 
-addSexOverall <- function(result, sex){
-  if(sex){
+addSexOverall <- function(result, sex) {
+  if (sex) {
     result <- result |> rbind(
       result |>
         dplyr::group_by(.data$age_group, .data$additional_level, .data$variable_name, .data$additional_name) |>
@@ -351,15 +400,14 @@ addSexOverall <- function(result, sex){
   return(result)
 }
 
-createEmptyIntervalTable <- function(interval){
-  if(interval == "overall"){
+createEmptyIntervalTable <- function(interval) {
+  if (interval == "overall") {
     tibble::tibble(
       "sex" = as.character(),
       "age_group" = as.character(),
       "estimate_value" = as.double()
     )
-
-  }else{
+  } else {
     tibble::tibble(
       "time_interval" = as.character(),
       "sex" = as.character(),
@@ -367,21 +415,20 @@ createEmptyIntervalTable <- function(interval){
       "estimate_value" = as.double()
     )
   }
-
 }
 
-getOmopTableStartDate <- function(omopTable, date){
+getOmopTableStartDate <- function(omopTable, date) {
   omopTable |>
     dplyr::summarise("start_date" = min(.data[[date]], na.rm = TRUE)) |>
     dplyr::collect() |>
-    dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data$start_date))),"-01-01"))) |>
+    dplyr::mutate("start_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data$start_date))), "-01-01"))) |>
     dplyr::pull("start_date")
 }
 
-getOmopTableEndDate   <- function(omopTable, date){
+getOmopTableEndDate <- function(omopTable, date) {
   omopTable |>
     dplyr::summarise("end_date" = max(.data[[date]], na.rm = TRUE)) |>
     dplyr::collect() |>
-    dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data$end_date))),"-12-31"))) |>
+    dplyr::mutate("end_date" = as.Date(paste0(as.character(as.integer(clock::get_year(.data$end_date))), "-12-31"))) |>
     dplyr::pull("end_date")
 }
