@@ -5,6 +5,7 @@
 #' @param estimates Estimates to summarise the variables of interest (
 #' `records per person`, `duration in days` and
 #' `days to next observation period`).
+#' @param byOrdinal Boolean variable. Whether to stratify by the ordinal observation period (e.g., 1st, 2nd, etc.) (TRUE) or simply analyze overall data (FALSE)
 #' @param ageGroup A list of age groups to stratify results by.
 #' @param sex Boolean variable. Whether to stratify by sex (TRUE) or not
 #' (FALSE).
@@ -31,7 +32,9 @@ summariseObservationPeriod <- function(observationPeriod,
                                        estimates = c(
                                          "mean", "sd", "min", "q05", "q25",
                                          "median", "q75", "q95", "max",
-                                         "density"),
+                                         "density"
+                                       ),
+                                       byOrdinal = TRUE,
                                        ageGroup = NULL,
                                        sex = FALSE,
                                        dateRange = NULL) {
@@ -47,7 +50,7 @@ summariseObservationPeriod <- function(observationPeriod,
   ) |>
     dplyr::pull("estimate_name")
   omopgenerics::assertChoice(estimates, opts, unique = TRUE)
-  tablePrefix <-  omopgenerics::tmpPrefix()
+  tablePrefix <- omopgenerics::tmpPrefix()
   strata <- c(list(character()), omopgenerics::combineStrata(strataCols(sex = sex, ageGroup = ageGroup)))
 
   set <- createSettings(result_type = "summarise_observation_period", study_period = dateRange)
@@ -58,11 +61,11 @@ summariseObservationPeriod <- function(observationPeriod,
   } else {
     obs <- addStrataToPeopleInObservation(cdm, ageGroup$age_group, sex, tablePrefix, dateRange) |>
       dplyr::select(
-        "person_id", dplyr::any_of(c("sex","age_group")),
+        "person_id", dplyr::any_of(c("sex", "age_group")),
         "obs_start" = "observation_period_start_date",
         "obs_end" = "observation_period_end_date"
       ) |>
-      dplyr::group_by(.data$person_id, dplyr::across(dplyr::any_of(c("sex","age_group")))) |>
+      dplyr::group_by(.data$person_id, dplyr::across(dplyr::any_of(c("sex", "age_group")))) |>
       dplyr::arrange(.data$obs_start) |>
       dplyr::mutate("next_start" = dplyr::lead(.data$obs_start)) %>%
       dplyr::mutate(
@@ -71,21 +74,21 @@ summariseObservationPeriod <- function(observationPeriod,
         "id" = as.integer(dplyr::row_number())
       ) |>
       dplyr::ungroup() |>
-      dplyr::select("person_id", "id", "duration", "next_obs", dplyr::any_of(c("sex","age_group"))) |>
+      dplyr::select("person_id", "id", "duration", "next_obs", dplyr::any_of(c("sex", "age_group"))) |>
       dplyr::collect()
-    if (all(is.na(obs$next_obs))){
+    if (all(is.na(obs$next_obs))) {
       obs <- obs |>
         dplyr::select(!"next_obs")
     }
 
-   if (dim(obs)[1]==0){
-     return(omopgenerics::emptySummarisedResult(settings = set))
-   }
+    if (dim(obs)[1] == 0) {
+      return(omopgenerics::emptySummarisedResult(settings = set))
+    }
 
     obsSr <- obs |>
       PatientProfiles::summariseResult(
         strata = strata,
-        group = "id",
+        group = "id"[byOrdinal],
         includeOverallGroup = TRUE,
         includeOverallStrata = TRUE,
         variables = c("duration", "next_obs"),
@@ -93,21 +96,22 @@ summariseObservationPeriod <- function(observationPeriod,
       ) |>
       suppressMessages() |>
       dplyr::mutate(variable_name = dplyr::if_else(.data$variable_name == "number records", "Number records",
-                                                   dplyr::if_else(.data$variable_name == "number subjects", "Number subjects" , .data$variable_name))) |>
-        dplyr::union_all(
-          obs |>
-            dplyr::group_by(.data$person_id, dplyr::across(dplyr::any_of(c("sex","age_group")))) |>
-            dplyr::tally(name = "n") |>
-            dplyr::ungroup() |>
-            PatientProfiles::summariseResult(
-              variables = c("n"),
-              estimates = estimates,
-              counts = F,
-              strata = strata
-            ) |>
-            suppressMessages()
+        dplyr::if_else(.data$variable_name == "number subjects", "Number subjects", .data$variable_name)
+      )) |>
+      dplyr::union_all(
+        obs |>
+          dplyr::group_by(.data$person_id, dplyr::across(dplyr::any_of(c("sex", "age_group")))) |>
+          dplyr::tally(name = "n") |>
+          dplyr::ungroup() |>
+          PatientProfiles::summariseResult(
+            variables = c("n"),
+            estimates = estimates,
+            counts = F,
+            strata = strata
           ) |>
-      addOrdinalLevels() |>
+          suppressMessages()
+      ) |>
+      addOrdinalLevels(byOrdinal = byOrdinal) |>
       dplyr::filter(.data$variable_name != "Number records" | .data$group_level == "all") |>
       arrangeSr(estimates)
   }
@@ -129,12 +133,13 @@ summariseObservationPeriod <- function(observationPeriod,
   return(obsSr)
 }
 
-addOrdinalLevels <- function(x) {
+addOrdinalLevels <- function(x, byOrdinal) {
+  if (byOrdinal) {
   group_cols <- omopgenerics::groupColumns(x)
-  x<-x|>omopgenerics::splitGroup()
+  x <- x |> omopgenerics::splitGroup()
 
   xx <- suppressWarnings(as.integer(x$id))
-  desena <- (floor(xx/10)) %% 10
+  desena <- (floor(xx / 10)) %% 10
   unitat <- xx %% 10
   val <- rep("all", length(xx))
   id0 <- !is.na(xx)
@@ -147,10 +152,16 @@ addOrdinalLevels <- function(x) {
   val[id] <- paste0(xx[id], "rd")
 
   x <- x |>
-    dplyr::mutate("group_level" = .env$val,
-                  "group_name" = "observation_period_ordinal") |>
+    dplyr::mutate(
+      "group_level" = .env$val,
+      "group_name" = "observation_period_ordinal"
+    ) |>
     dplyr::select(-c("id"))
-
+  } else {
+  x <- x |>
+      dplyr::mutate("group_level" = "all",
+                    "group_name" = "observation_period_ordinal")
+}
   return(x)
 }
 arrangeSr <- function(x, estimates) {
@@ -177,7 +188,7 @@ arrangeSr <- function(x, estimates) {
     dplyr::union_all(
       tidyr::expand_grid(
         "variable_name" = c("n", "duration", "next_obs"),
-        "group_level"   = group,
+        "group_level" = group,
         "strata_level" = lev,
         "estimate_name" = estimates
       )
