@@ -6,7 +6,7 @@
 #'
 #'
 tableConceptIdCounts <- function(result,
-                             type = "gt") {
+                                 type = "gt") {
   # initial checks
   rlang::check_installed("visOmopResults")
   omopgenerics::validateResultArgument(result)
@@ -15,9 +15,10 @@ tableConceptIdCounts <- function(result,
   # subset to result_type of interest
   result <- result |>
     omopgenerics::filterSettings(
-      .data$result_type == "summarise_concept_id_counts")|>
+      .data$result_type == "summarise_concept_id_counts"
+    ) |>
     omopgenerics::splitStrata() |>
-    dplyr::arrange(.data$variable_name, dplyr::across(dplyr::all_of(strata_cols)), .data$additional_level)|>
+    dplyr::arrange(.data$variable_name, dplyr::across(dplyr::all_of(strata_cols)), .data$additional_level) |>
     omopgenerics::uniteStrata(strata_cols)
 
   # check if it is empty
@@ -36,20 +37,17 @@ tableConceptIdCounts <- function(result,
   if ("count_subjects" %in% estimate_names) {
     estimateName <- c(estimateName, "N persons" = "<count_subjects>")
   }
- header <- c("cdm_name", "estimate_name")
+  header <- c("cdm_name", "estimate_name")
 
   result |>
     formatColumn(c("variable_name", "variable_level")) |>
     visOmopResults::visOmopTable(
       type = type,
       estimateName = estimateName,
-        header = header,
-        rename = c("Database name" = "cdm_name", "Concept name" = "variable_name", "Concept id" = "variable_level" ),
-        groupColumn = c(omopgenerics::additionalColumns(result)),
-      columnOrder = c("omop_table","variable_name", "variable_level", strata_cols),
-
-
-      .options = list(groupAsColumn = TRUE, merge = "all_columns"
-      )
-      )
+      header = header,
+      rename = c("Database name" = "cdm_name", "Concept name" = "variable_name", "Concept id" = "variable_level"),
+      groupColumn = c(omopgenerics::additionalColumns(result)),
+      columnOrder = c("omop_table", "variable_name", "variable_level", strata_cols),
+      .options = list(groupAsColumn = TRUE, merge = "all_columns")
+    )
 }
